@@ -3,8 +3,8 @@ from .geoip import geoip
 from .cache import Cache
 from .model import Geolocation
 
-from .urllib_geoip import (geoip as urllib_geoip)
-from .requests_geoip import (geoip as requests_geoip)
+from .urllib_geoip import (geoip as urllib_geoip, whoami as urllib_whoami)
+from .requests_geoip import (geoip as requests_geoip, whoami as requests_whoami)
 
 from .version import (
     __author__, __version__, author_info, package_info, package_license,
@@ -29,5 +29,7 @@ __all__ = (
     "geoip",
 
     "urllib_geoip",
+    "urllib_whoami",
     "requests_geoip",
+    "requests_whoami"
 )
